#
# spec file for package libfabric (Version 1.2.0)
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
Name:           libfabric
Summary:        User-space RDMA Fabric Interfaces
Version:        1.4.1
Release:        1.5
License:        GPL-2.0 or BSD-2-Clause
Group:          System Environment/Libraries
Source:         https://github.com/ofiwg/libfabric/releases/download/v1.4.1/libfabric-1.4.1.tar.bz2
Source1:        baselibs.conf
Patch0:         libfabric-libtool.patch
Url:            http://www.github.com/ofiwg/libfabric
Prefix:         ${_prefix}
BuildRequires: libnl3-devel
BuildRequires: librdmacm-devel
BuildRequires: libibverbs-devel
BuildRequires: infinipath-psm-devel
BuildRequires: libpsm2-devel
BuildRequires: automake autoconf libtool
BuildRequires: pkg-config
#Currently *only* builds on x86_64 as it is dependent on libpsm2
ExclusiveArch:  x86_64
%define lib_major 1

%description
libfabric provides a user-space API to access high-performance fabric
services, such as RDMA. This package only contains the fi_info binary.

%package       -n libfabric%{lib_major}
Summary:       Libfabric runtime libary
Group:         System/Libraries


%description -n libfabric%{lib_major}
libfabric provides a user-space API to access high-performance fabric
services, such as RDMA. This package contains the runtime library.


%package        devel
Summary:        Development files for the libfabric library
Group:          Development/Libraries/C and C++
Requires:       libfabric = %{version}

%description    devel
Development files for the libfabric library.

%prep
%setup -q
%patch0 -p1

%build
rm config/libtool.m4
autoreconf -fi
# defaults: with-dlopen and without-valgrind can be over-rode:
%configure %{?_without_dlopen} %{?_with_valgrind} \
	--enable-sockets --enable-verbs --enable-usnic --enable-psm \
        --disable-static  --enable-psm2
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

# remove unpackaged files from the buildroot
rm -f %{buildroot}%{_libdir}/*.la

%post -n libfabric%{lib_major} -p /sbin/ldconfig
%postun -n libfabric%{lib_major} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_bindir}/*

%{_mandir}/man1/*
%{_mandir}/man3/fi_av.3.gz
%{_mandir}/man3/fi_cm.3.gz
%{_mandir}/man3/fi_cntr.3.gz
%{_mandir}/man3/fi_control.3.gz
%{_mandir}/man3/fi_cq.3.gz
%{_mandir}/man3/fi_domain.3.gz
%{_mandir}/man3/fi_endpoint.3.gz
%{_mandir}/man3/fi_errno.3.gz
%{_mandir}/man3/fi_eq.3.gz
%{_mandir}/man3/fi_fabric.3.gz
%{_mandir}/man3/fi_getinfo.3.gz
%{_mandir}/man3/fi_mr.3.gz
%{_mandir}/man3/fi_msg.3.gz
%{_mandir}/man3/fi_poll.3.gz
%{_mandir}/man3/fi_rma.3.gz
%{_mandir}/man3/fi_tagged.3.gz
%{_mandir}/man3/fi_trigger.3.gz
%{_mandir}/man3/fi_version.3.gz
%{_mandir}/man3/fi_accept.3.gz
%{_mandir}/man3/fi_alias.3.gz
%{_mandir}/man3/fi_atomic.3.gz
%{_mandir}/man3/fi_atomic_valid.3.gz
%{_mandir}/man3/fi_atomicmsg.3.gz
%{_mandir}/man3/fi_atomicv.3.gz
%{_mandir}/man3/fi_av_bind.3.gz
%{_mandir}/man3/fi_av_insert.3.gz
%{_mandir}/man3/fi_av_insertsvc.3.gz
%{_mandir}/man3/fi_av_lookup.3.gz
%{_mandir}/man3/fi_av_open.3.gz
%{_mandir}/man3/fi_av_remove.3.gz
%{_mandir}/man3/fi_av_straddr.3.gz
%{_mandir}/man3/fi_cancel.3.gz
%{_mandir}/man3/fi_close.3.gz
%{_mandir}/man3/fi_cntr_add.3.gz
%{_mandir}/man3/fi_cntr_open.3.gz
%{_mandir}/man3/fi_cntr_read.3.gz
%{_mandir}/man3/fi_cntr_set.3.gz
%{_mandir}/man3/fi_cntr_wait.3.gz
%{_mandir}/man3/fi_compare_atomic.3.gz
%{_mandir}/man3/fi_compare_atomic_valid.3.gz
%{_mandir}/man3/fi_compare_atomicmsg.3.gz
%{_mandir}/man3/fi_compare_atomicv.3.gz
%{_mandir}/man3/fi_connect.3.gz
%{_mandir}/man3/fi_cq_open.3.gz
%{_mandir}/man3/fi_cq_read.3.gz
%{_mandir}/man3/fi_cq_readerr.3.gz
%{_mandir}/man3/fi_cq_readfrom.3.gz
%{_mandir}/man3/fi_cq_sread.3.gz
%{_mandir}/man3/fi_cq_sreadfrom.3.gz
%{_mandir}/man3/fi_cq_strerror.3.gz
%{_mandir}/man3/fi_cq_signal.3.gz
%{_mandir}/man3/fi_domain_bind.3.gz
%{_mandir}/man3/fi_domain_query.3.gz
%{_mandir}/man3/fi_dupinfo.3.gz
%{_mandir}/man3/fi_enable.3.gz
%{_mandir}/man3/fi_ep_bind.3.gz
%{_mandir}/man3/fi_eq_open.3.gz
%{_mandir}/man3/fi_eq_read.3.gz
%{_mandir}/man3/fi_eq_readerr.3.gz
%{_mandir}/man3/fi_eq_sread.3.gz
%{_mandir}/man3/fi_eq_strerror.3.gz
%{_mandir}/man3/fi_eq_write.3.gz
%{_mandir}/man3/fi_fetch_atomic.3.gz
%{_mandir}/man3/fi_fetch_atomic_valid.3.gz
%{_mandir}/man3/fi_fetch_atomicmsg.3.gz
%{_mandir}/man3/fi_fetch_atomicv.3.gz
%{_mandir}/man3/fi_freeinfo.3.gz
%{_mandir}/man3/fi_getname.3.gz
%{_mandir}/man3/fi_getopt.3.gz
%{_mandir}/man3/fi_getpeer.3.gz
%{_mandir}/man3/fi_inject.3.gz
%{_mandir}/man3/fi_injectdata.3.gz
%{_mandir}/man3/fi_inject_atomic.3.gz
%{_mandir}/man3/fi_inject_write.3.gz
%{_mandir}/man3/fi_inject_writedata.3.gz
%{_mandir}/man3/fi_join.3.gz
%{_mandir}/man3/fi_leave.3.gz
%{_mandir}/man3/fi_listen.3.gz
%{_mandir}/man3/fi_mr_bind.3.gz
%{_mandir}/man3/fi_mr_desc.3.gz
%{_mandir}/man3/fi_mr_key.3.gz
%{_mandir}/man3/fi_mr_reg.3.gz
%{_mandir}/man3/fi_mr_regattr.3.gz
%{_mandir}/man3/fi_mr_regv.3.gz
%{_mandir}/man3/fi_open.3.gz
%{_mandir}/man3/fi_open_ops.3.gz
%{_mandir}/man3/fi_passive_ep.3.gz
%{_mandir}/man3/fi_pep_bind.3.gz
%{_mandir}/man3/fi_poll_add.3.gz
%{_mandir}/man3/fi_poll_del.3.gz
%{_mandir}/man3/fi_poll_open.3.gz
%{_mandir}/man3/fi_read.3.gz
%{_mandir}/man3/fi_readmsg.3.gz
%{_mandir}/man3/fi_readv.3.gz
%{_mandir}/man3/fi_recv.3.gz
%{_mandir}/man3/fi_recvmsg.3.gz
%{_mandir}/man3/fi_recvv.3.gz
%{_mandir}/man3/fi_reject.3.gz
%{_mandir}/man3/fi_rx_addr.3.gz
%{_mandir}/man3/fi_rx_size_left.3.gz
%{_mandir}/man3/fi_scalable_ep_bind.3.gz
%{_mandir}/man3/fi_send.3.gz
%{_mandir}/man3/fi_senddata.3.gz
%{_mandir}/man3/fi_sendmsg.3.gz
%{_mandir}/man3/fi_sendv.3.gz
%{_mandir}/man3/fi_setname.3.gz
%{_mandir}/man3/fi_setopt.3.gz
%{_mandir}/man3/fi_shutdown.3.gz
%{_mandir}/man3/fi_strerror.3.gz
%{_mandir}/man3/fi_tinject.3.gz
%{_mandir}/man3/fi_tinjectdata.3.gz
%{_mandir}/man3/fi_tostr.3.gz
%{_mandir}/man3/fi_trecv.3.gz
%{_mandir}/man3/fi_trecvmsg.3.gz
%{_mandir}/man3/fi_trecvv.3.gz
%{_mandir}/man3/fi_tsend.3.gz
%{_mandir}/man3/fi_tsenddata.3.gz
%{_mandir}/man3/fi_tsendmsg.3.gz
%{_mandir}/man3/fi_tsendv.3.gz
%{_mandir}/man3/fi_tx_size_left.3.gz
%{_mandir}/man3/fi_wait.3.gz
%{_mandir}/man3/fi_wait_open.3.gz
%{_mandir}/man3/fi_write.3.gz
%{_mandir}/man3/fi_writedata.3.gz
%{_mandir}/man3/fi_writemsg.3.gz
%{_mandir}/man3/fi_writev.3.gz
%{_mandir}/man3/fi_ep.3.gz
%{_mandir}/man7/fabric.7.gz
%{_mandir}/man7/fi_provider.7.gz
%{_mandir}/man7/fi_direct.7.gz
%{_mandir}/man7/fi_sockets.7.gz
%{_mandir}/man7/fi_verbs.7.gz
%{_mandir}/man7/fi_usnic.7.gz
%{_mandir}/man7/fi_psm.7.gz
%{_mandir}/man7/fi_psm2.7.gz
%{_mandir}/man3/fi_trywait.3.gz
%{_mandir}/man7/fi_udp.7.gz

%files -n libfabric%{lib_major}
%defattr(-,root,root,-)
%{_libdir}/%{name}.so.%{lib_major}*
%doc AUTHORS COPYING README

%files devel
%defattr(-,root,root)
%{_libdir}/%{name}.so
%dir %{_includedir}/rdma
%{_includedir}/rdma/fabric.h
%{_includedir}/rdma/fi_atomic.h
%{_includedir}/rdma/fi_cm.h
%{_includedir}/rdma/fi_domain.h
%{_includedir}/rdma/fi_eq.h
%{_includedir}/rdma/fi_rma.h
%{_includedir}/rdma/fi_endpoint.h
%{_includedir}/rdma/fi_errno.h
%{_includedir}/rdma/fi_tagged.h
%{_includedir}/rdma/fi_trigger.h
%{_includedir}/rdma/fi_ext_usnic.h


%{_libdir}/pkgconfig/%{name}.pc
%changelog
* Fri Mar 10 2017 josef.moellers@suse.com
- PSM provider notes
  - Defer initialization of the PSM library to allow runtime selection from
    different versions of the same provider before fi_getinfo is called.
- PSM2 provider notes
  - Defer initialization of the PSM2 library to allow runtime selection from
    different versions of the same provider before fi_getinfo is called.
  - General bug fixes.
- UDP provider notes
  - Fix setting address format in fi_getinfo call.
- usNIC provider notes
  - Fixed compilation issues with newer versions of libibverbs.
  (fate#321883)
* Mon Jan 16 2017 ndas@suse.de
- Updated to version 1.4.0 for general stability(fate#321883)
- Summary of changes as follow:
  - Add new options, `-f` and `-d`, to fi_info that can be used to
  specify hints about the fabric and domain name. Change port to `-P`
  and provider to `-p` to be more in line with fi_pingpong.
  * GNI provider notes
  - General bug fixes, plugged memory leaks, performance improvements,
  improved error handling and warning messages, etc.
  - Additional API support:
  - FI_THREAD_COMPLETION
  - FI_RMA_EVENT
  - iov length up to 8 for messaging data transfers
  * PSM provider notes
  - General bug fixes
  - Use utility provider for EQ, wait object, and poll set
  - Allow multi-recv to post buffer larger than message size limit
  * PSM2 provider notes
  - General bug fixes
  - Add support for multi-iov RMA read and aromic operations
  - Allow multi-recv to post buffer larger than message size limit
  * Verbs provider notes
  - Add fork support. It is enabled by default and can be turned off by
  setting the FI_FORK_UNSAFE variable to "yes". This can improve
  performance of memory registrations but also makes fork unsafe. The
  following are the limitations of fork support:
  - Fabric resources like endpoint, CQ, EQ, etc. should not be used in
    the forked process.
  - The memory registered using fi_mr_reg has to be page aligned since
    ibv_reg_mr marks the entire page that a memory region belongs to
    as not to be re-mapped when the process is forked (MADV_DONTFORK).
  - Fix a bug where source address info was not being returned in
  fi_info when destination node is specified.
* Fri May  6 2016 nads@suse.de
- Updated to version 1.3.0 for better PSM2 support as suggested by
  fate#319253, comment #9.
  [*libfabric-libtool.patch]
  Summary of changes as follow:
  * PSM provider notes
  - Remove PSM2 related code.
  * PSM2 provider notes
  - Add support for multi-iov send, tagged send, and RMA write.
  - Use utility provider for EQ, wait object, and poll set.
  * GNI provider notes
  - General bug fixes, plugged memory leaks, etc.
  - Added support for the following APIs:
  - fi_endpoint: fi_getopt, fi_setopt, fi_rx_size_left, fi_tx_size_left, fi_stx_context
  - fi_cq: fi_sread, fi_sreadfrom
  - fi_msg: FI_MULTI_RECV (flag)
  - fi_domain: FI_PROGRESS_AUTO (flag)
  - fi_direct: FI_DIRECT
  - Added support for FI_EP_DGRAM (datagram endpoint):
  - Memory registration improvements:
  - Initial support for Cray Cluster Compatibility Mode (CCM)
  * MXM provider notes
  - Initial release
  * Sockets provider notes
  - Enable FABRIC_DIRECT
  - Enable sockets-provider to run on FreeBSD
  - Add support for fi_trywait
  - Add support for map_addr in shared-av creation
  - Add shared-av support on OSX
  - General bug fixes
  * UDP provider notes
  - Initial release
  * usNIC provider notes
  - Implement fi_recvv and fi_recvmsg for FI_EP_RDM. [PR #1594]
  - Add support for FI_INJECT flag in the FI_EP_RDM implementation of fi_sendv.
  [PR #1594]
  - Handle FI_PEEK flag in fi_eq_sread. [PR #1758]
  - Implement waitsets [PR #1893]
  - Implement fi_trywait [PR #1893]
  - Fix progress thread deadlock [PR #1893]
  - Implement FD based CQ sread [PR #1893]
  * Verbs provider notes
  - Add support for fi_trywait
  - verbs/RDM
  - Add support for RMA operations.
  - Add support for fi_cq_sread and fi_cq_sreadfrom
  - Rework connection management to make it work with fabtests and also allow
    connection to self.
  - Other bug fixes and performance improvements.
* Wed Apr  6 2016 ndas@suse.de
- Moved man pages to main package.
- Fixed invalid library group.
* Wed Apr  6 2016 ndas@suse.de
- Packaging version 1.2.0 for fate#319253
* Fri Feb 12 2016 pth@suse.de
- Use explicit file list instead of wildcards
- Package fi_info.
- Remove libtool.m4 from the package so that autoreconf installs
  a current version.
* Thu Feb 11 2016 pth@suse.de
- Initial package, based on the OFED specfile for libfabric
- Add libfabric-libtool.patch to disable static builds by default.
